
* THIS VERSION: Sep 2023

// ************************
// balancing tests: Table 1
// ************************

// See here:
// http://www.promisingpractices.net/program.asp?programid=136
//
// The 985 infants were categorized into two birth weight groups:
// greater than 2,000g = "heavier" and less than or equal to 2,000g = "lighter"
// One-third of the sample came from the heavier group and two-thirds from the lighter group.
// Within each weight group, one-third of the subjects were randomized to the intervention group
// and two-thirds to the control group.
// Stratification variable: strata (=1 if "heavier")
// table strata, c(mean INV_BW min INV_BW max INV_BW)

// Note that:
// The research design included stratification by eight sites and two birth-weight groups (see JAMA paper)

local filewrite="replace"

foreach v in $B $X {

	cap drop `v'_std
	*egen `v'_std = std(`v') // activate to std variables
	gen `v'_std = `v' // Note that variables are NOT std

	// baseline, all sample
	
	qui sum `v'_std if $D == 0
	local sd = round(r(sd),0.001)
	local m = round(r(mean),0.001)
	
	// differences, all sample
	
	reg `v'_std $D, robust
	outreg2 using "${foldlog}\balancing.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, All)
	local filewrite="append"

	// baseline, "heavier"
	
	qui sum `v'_std if $D == 0 & strata == 1
	local sd = round(r(sd),0.001)
	local m = round(r(mean),0.001)
	
	// differences, "heavier"
	
	reg `v'_std $D if strata == 1, robust
	outreg2 using "${foldlog}\balancing.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Heavier)
	
	// baseline, "lighter"
	
	qui sum `v'_std if $D == 0 & strata == 0
	local sd = round(r(sd),0.001)
	local m = round(r(mean),0.001)
	
	// differences, "lighter"
	
	reg `v'_std $D if strata == 0, robust
	outreg2 using "${foldlog}\balancing.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Lighter)
}

// ************************
// average effects: Table 2
// ************************

local filewrite="replace"

foreach v in $Y {

	cap drop `v'_std
	*egen `v'_std = std(`v') // activate to std variables
	gen `v'_std = `v' // Note that variables are NOT std

	// baseline, all sample
	
	qui sum `v'_std if $D == 0
	local sd = round(r(sd),0.001)
	local m = round(r(mean),0.001)
	
	// differences, all sample
	
	reg `v'_std $D $X, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, All, Infant Demographics, NO, Mother Demographics, NO)
	local filewrite="append"

	reg `v'_std $D i.site i.strata $X, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, All, Infant Demographics, NO, Mother Demographics, YES)
	
	reg `v'_std $D i.site i.strata $X $B, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, All, Infant Demographics, YES, Mother Demographics, YES)
	
	// baseline, "heavier"
	
	qui sum `v'_std if $D == 0 & strata == 1
	local sd = round(r(sd),0.001)
	local m = round(r(mean),0.001)
	
	// differences, "heavier"
	
	reg `v'_std $D $X if strata == 1, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Heavier, Infant Demographics, NO, Mother Demographics, NO)
	
	reg `v'_std $D i.site $X if strata == 1, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Heavier, Infant Demographics, NO, Mother Demographics, YES)

	reg `v'_std $D i.site $X $B if strata == 1, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Heavier, Infant Demographics, YES, Mother Demographics, YES)

	// baseline, "lighter"
	
	qui sum `v'_std if $D == 0 & strata == 0
	local sd = round(r(sd),0.001)
	local m = round(r(mean),0.001)
	
	// differences, "lighter"
	
	reg `v'_std $D $X if strata == 0, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Lighter, Infant Demographics, NO, Mother Demographics, NO)

	reg `v'_std $D i.site $X if strata == 0, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Lighter, Infant Demographics, NO, Mother Demographics, YES)
	
	reg `v'_std $D i.site $X $B if strata == 0, robust
	outreg2 using "${foldlog}\mean-outcomes.xls", keep($D) `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Baseline Mean, `m', Baseline StdDev, "[`sd']", Sample, Lighter, Infant Demographics, YES, Mother Demographics, YES)
	
}





 
 