
// Last edited: Erich, December 19, 2019

// this code reads data from:
// http://www.icpsr.umich.edu/icpsrweb/HMCA/studies/9795?paging.startRow=51
// Data description: page 23 of the codebook file labeled with (2)

// also reads data from:
// http://www.icpsr.umich.edu/icpsrweb/HMCA/studies/23580/version/2
// http://www.promisingpractices.net/program.asp?programid=136


clear all

*****************************************************
*****************************************************
*****************************************************

#delimit ;
infix 1 lines

/* this is the Infant Inventory Dataset */
/* page 239 of the codebook file labeled with (2) */

1:   IHDP       1-4                                                              
1:   str TG     5                                                                
1:   BW         6-9                                                              
1:   ANGA       16-17                                                            
1:   str SEX    24                                                               
1:   TWINIHDP   25-28                                                            
1:   str RDATE  29-34                                                         
1:   str LCDATE 35-40                                                         
1:   str DISPC  41-42                                                          
1:   DATACOLL   43                                                               
1:   str BWG    44                                                               
1:   str SITE   45-47                                                          
1:   PAG        48              
                                                 
using "${folddata}\09795-0001-Data.txt";
#delimit cr

label var IHDP     "IHDP Number"                                                              
label var TG       "Treatment Group"                                                                
label var BW       "Birth Weight"                                                              
label var ANGA     "Analysis Gestational Age"                                                            
label var SEX      "Infant Sex"                                                               
label var TWINIHDP "Twin IHDP Number"                                                            
label var RDATE    "Randomization Date"                                                         
label var LCDATE   "Date of Last Status Change"                                                         
label var DISPC    "Disposition Code"                                                          
label var DATACOLL "Data Collection Group"                                                               
label var BWG      "Birth Weight Group"                                                               
label var SITE     "Site Name"                                                          
label var PAG      "Primary Analysis Group"                                                               

sort IHDP
compress

saveold "${folddata}\Inventory-Dataset.dta", replace

*****************************************************
*****************************************************
*****************************************************

clear all

#delimit ;
infix 9 lines

/* this is the Primary Analysis Dataset */
/* page 243 of the codebook file labeled with (2) */
/* only selected variables are considered */

/* Basic variables */

1:   IHDP      1-4                                                              
1:   str SITE  5-7                                                              
1:   str BWG   8                                                                
1:   str TG    9 

/* Baseline variables */

1:   INV_BW    44-47                                                            
1:   INV_SEX   48                                                               
1:   F3AMAGE   49-50                                                            
1:   F3BV59    51                                                               
1:   F3BV60    52                                                               
1:   BLACK     53                                                               
1:   HISPANIC  54                                                               
1:   NHIBW     55-57
1:   INV_ANGA  63-64                                                            
1:   BRTH_ORD  70                                                               
1:   F3BV64    71                                                               
2:   F3AV5     22-23                                                            
3:   F3AV4     65-66                                                            
3:   BMI_B     67-72                                                             

/* Outcomes - see JHR article, page 951 */

1:   F57_1_    10-12                                                            
2:   F23DICCA  30-32                                                           
2:   F39DICCA  36-38                                                           
2:   F24DICCA  33-35                                                            
1:   ACTPS_36  13-15                                                            
1:   STETO_36  16-20                                                             
1:   GHRI_36   21-22                                                            
1:   F63V7A    23-29                                                              
1:   BMI_36    30-35                                                              
1:   THCS_CUM  36-41                                                            
1:   SHCI_CUM  43          

using "${folddata}\09795-0003-Data.txt";                                                                               
#delimit cr

label var IHDP      "IHDP Number"
label var SITE      "Site Name"
label var BWG       "Birth Weight Group"
label var TG        "Treatment Group"
label var INV_BW    "Birth Weight (gm)"
label var INV_SEX   "Infant Sex (l=Male, 2=Female)"
label var F3AMAGE   "Maternal Age at Birth"
label var F3BV59    "Maternal Education"
label var F3BV60    "Maternal Race"
label var BLACK     "Black Maternal Race"
label var HISPANIC  "Hispanic Maternal Race"
label var NHIBW     "Neonatal Health Index"
label var INV_ANGA  "Analysis Gestational Age (weeks)"  
label var BRTH_ORD  "Birth Order (1, 2, 3+)"
label var F3BV64    "Marital Status at Birth"
label var F3AV5     "Head Circumference at Birth (cm)"
label var F3AV4     "Infant Length at Birth (cm)"
label var BMI_B     "Body Mass Index at Birth"                                                            
label var F23DICCA  "Bayley Mental Development Index at 12 Months"                                                           
label var F39DICCA  "Bayley Mental Development Index at 24 Months"                                                           
label var F24DICCA  "Bayley PDI (Corrected Age) at 12 Months"                                                            
label var F57_1_    "Stanford Binet IQ (Corrected Age) at 36M"
label var ACTPS_36  "Achenbach Total Prob. Sum Score at 36M"	
label var STETO_36  "Stein Total Score at 36 Months"
label var GHRI_36   "Rand General Health Ratings Score at 36M"
label var F63V7A    "Infant Length at at 36 Months (cm)"
label var BMI_36    "Body Mass Index at 36 Months"
label var THCS_CUM  "Mother Report: Morbidity Index (Yl-Y3)"
label var SHCI_CUM  "Mother Rpt: Serious Mrbdty Index (Yl-Y3)"

sort IHDP
compress

saveold "${folddata}\Primary-Analysis-Dataset.dta", replace

*****************************************************
*****************************************************
*****************************************************

clear all

#delimit ;
infix 6 lines

/* this is the Summary Scores Dataset */
/* page 261 of the codebook file labeled with (3) */
/* only selected variables are considered */

/* Basic variables */

1:   IHDP      1-4                                                              
1:   str SITE  5-7                                                              
1:   str BWG   8                                                                
1:   str TG    9 
1:   PAG       10                                                               

using "${folddata}\09795-0005-Data.txt";                                                                               
#delimit cr

label var IHDP      "IHDP Number"
label var SITE      "Site Name"
label var BWG       "Birth Weight Group"
label var TG        "Treatment Group"
label var PAG       "Primary Analysis Group"                                                               

sort IHDP
compress

saveold "${folddata}\Summary-Scores-Dataset.dta", replace

*****************************************************
*****************************************************
*****************************************************

// this is a patch to read income data
// I used the this link:
// https://www.icpsr.umich.edu/web/HMCA/studies/9795/datadocumentation
// the section I considered in F18
// page 442 of the codebook file labeled with (2)
// I selected only income
// see page 215 for codes on missing variables

clear all

#delimit ;
infix 8 lines

1:   IHDP      1-4                                                              
7:   str V61   54-55

using "${folddata}\09795-0035-Data.txt";                                                                               

replace V61 = "" if V61 == "98" | V61 == "99" | V61 == "C" | V61 == "L" | V61 == "Q";

gen income = real(V61);

label def i 1 "less than 5000"
            2 "5000-7499"
			3 "7500-9999"
            4 "10000-14999"
            5 "15000-19999"
            6 "20000-24999"
            7 "25000-34999"
            8 "35000-49999"
            9 "more than 50000";
			
label values income i;

#delimit cr

keep IHDP income 
sort IHDP
compress

saveold "${folddata}\F18-Dataset.dta", replace

exit


/*

// PRIMARY ANALYSIS DATASET CODEBOOK
// bits from the SAS file
// go to page 243 of the pdf/manual coded with (2)

1:   ACTPS_36  13-15                                                            
1:  @16 STETO_36 5.3                                                            
1:   GHRI_36   21-22                                                            
1:  @23 F63V7A 7.3                                                              
1:  @30 BMI_36 6.3                                                              
1:  @36 THCS_CUM 6.3                                                            
1:   SHCI_CUM  43                                                               
1:   SGA_BW    65                                                               
1:   SGA_BL    66                                                               
1:   SGA_BHC   67                                                               
1:   SGA_TOT   68                                                               
1:   F3BV62    69                                                               
1:   CHILDREN  77                                                               
1:   EXPOSURE  78                                                               
1:   F55V22    79                                                               
2:   F57_2_    1-3                                                              
2:   F40DICCA  44-46                                                            
2:   F58_1_    47-49                                                            
2:   RBCL_24   50-51                                                            
2:   RBCL_36   52-53                                                            
2:   ACTPT_36  54-55                                                            
2:   ACEXS_36  56-57                                                            
2:   ACEXT_36  58-59                                                            
2:   ACINS_36  60-61                                                            
2:   ACINT_36  62-63                                                            
2:   ACSWS_36  64-65                                                            
2:   ACDPS_36  66-67                                                            
2:   ACSPS_36  68-69                                                            
2:   ACSOS_36  70-71                                                            
2:   ACAGS_36  72-73                                                            
2:   ACDSS_36  74-75                                                            
2:   ACOPS_36  76-77                                                            
3:  @3 STETO_24 5.3                                                             
3:  @8 STEGH_24 5.3                                                             
3:  @13 STEAC_24 5.3                                                            
3:  @18 STETA_24 5.3                                                            
3:  @23 STEGH_36 5.3                                                            
3:  @28 STEAC_36 5.3                                                            
3:  @33 STETA_36 5.3                                                            
3:   GHRCH_12  38-39                                                            
3:   GHRRS_12  40-41                                                            
3:   GHRPH_12  42-43                                                            
3:   GHRI_12   44-45                                                            
3:   GHRCH_24  46-47                                                            
3:   GHRRS_24  48-49                                                            
3:   GHRPH_24  50-51                                                            
3:   GHRI_24   52-53                                                            
3:   GHRCH_36  54-55                                                            
3:   GHRRS_36  61-62                                                            
3:   GHRPH_36  63-64                                                            
3:   F9V11     73-76                                                            
3:   F9V12     77-78                                                            
4:  @1 BMI_0    6.3                                                             
4:   F13VB1    7-10                                                             
4:   F13VB2    11-12                                                            
4:  @13 BMI_4   6.3                                                             
4:   F17V8     19-23                                                            
4:   F17V9     24-25                                                            
4:  @26 BMI_8   6.3                                                             
4:   F21V6     32-36                                                            
4:   F21V7     37-38                                                            
4:  @39 BMI_12  6.3                                                             
4:   F31V6     45-49                                                            
4:   F31V7     50-51                                                            
4:  @52 BMI_18  6.3                                                             
4:   F37V8     58-62                                                            
4:   F37V9     63-64                                                            
4:  @65 BMI_24  6.3                                                             
4:   F50V8     71-75                                                            
4:   F50V9     76-78                                                            
5:  @1 BMI_30   6.3                                                             
5:  @7 F63V6A   6.3                                                             
5:  @13 THCS_1  6.3                                                             
5:  @19 THCS_2  6.3                                                             
5:  @25 THCS_3  5.3                                                             
5:   SHCI_1    30                                                               
5:   SHCI_2    31                                                               
5:   SHCI_3    32                                                               
5:   HOSP_1    33                                                               
5:   SURG_1    34                                                               
5:  @35 INJ_1 5.3                                                               
5:  @40 ILL_1 5.3                                                               
5:   HOSP_2    45                                                               
5:   SURG_2    46                                                               
5:  @47 INJ_2 5.3                                                               
5:  @52 ILL_2 5.3                                                               
5:   HOSP_3    57                                                               
5:   SURG_3    58                                                               
5:  @59 INJ_3 5.3                                                               
5:  @64 ILL_3 5.3                                                               
5:   HOSP_CUM  69-70                                                            
5:   SURG_CUM  71                                                               
5:  @72 INJ_CUM 5.3                                                             
6:  @6  ILL_CUM 6.3                                                             
6:   SHC_1     12                                                               
6:   SHC_2     13                                                               
6:   SHC_3     14                                                               
6:   SHC_CUM   15-16                                                            
6:   S_INJ_    17                                                               
6:   S_ILL_    18                                                               
6:  @19 NS_INJ_ 5.3                                                             
6:  @25 NS_ILL_ 6.3                                                             
6:   F9CCAGE   32-36                                                            
7:   F13CCAGE  1-4                                                              
7:   F16CCAGE  5-8                                                              
7:   F17CCAGE  9-12                                                             
7:   F20CCAGE  13-16                                                            
7:   F21CCAGE  17-20                                                            
7:   F23CCAGE  21-24                                                            
7:   F24CCAGE  25-28                                                            
7:   F30CCAGE  29-32                                                            
7:   F31CCAGE  33-36                                                            
7:   F36CCAGE  37-40                                                            
7:   F37CCAGE  41-44                                                            
7:   F38CCAGE  45-48                                                            
7:   F39CCAGE  49-52                                                            
7:   F40CCAGE  53-56                                                            
7:   F49CCAGE  57-60                                                            
7:   F50CCAGE  61-64                                                            
7:   F52CCAGE  65-68                                                            
7:   F54CCAGE  69-72                                                            
7:   F55CCAGE  73-76                                                            
7:   F56CCAGE  77-80                                                            
8:   F57CCAGE  1-4                                                              
8:   F58CCAGE  5-8                                                              
8:   F61CCAGE  9-12                                                             
8:   F63CCAGE  13-16                                                            
8:   RBCL24M   17-18                                                            
8:   RBCL36M   19-20                                                            
8:   ACTPS36M  21-23                                                            
8:   ACEXS36M  24-25                                                            
8:   ACINS36M  26-27                                                            
8:   ACSWS36M  28-29                                                            
8:   ACDPS36M  30-31                                                            
8:   ACSPS36M  32                                                               
8:   ACSOS36M  33-34                                                            
8:   ACAGS36M  36-37                                                            
8:   ACDSS36M  38-39                                                            
8:   ACOPS36M  40-41                                                            
8:   STETO24M  42-43                                                            
8:   STEGH24M  44-45                                                            
8:   STEAC24M  46-47                                                            
8:   STETA24M  48-49                                                            
8:   STETO36M  50-51                                                            
8:   STEGH36M  52-53                                                            
8:   STEAC36M  54-55                                                            
8:   STETA36M  56-57                                                            
8:   GHRCH12M  58                                                               
8:   GHRRS12M  59                                                               
8:   GHRPH12M  60                                                               
8:   GHRI12M   61                                                               
8:   GHRCH24M  62                                                               
8:   GHRRS24M  68                                                               
8:   GHRPH24M  69                                                               
8:   GHRI24M   70                                                               
8:   GHRCH36M  71                                                               
8:   GHRRS36M  72                                                               
8:   GHRPH36M  73                                                               
8:   GHRI36M   74                                                               
8:   HOSP_1M   75                                                               
8:   SURG_1M   76                                                               
8:   INJ_1M    77                                                               
8:   ILL_1M    78                                                               
8:   IMP_1M    79                                                               
8:   HOSP_2M   80                                                               
9:   SURG_2M   1                                                                
9:   INJ_2M    2                                                                
9:   ILL_2M    3                                                                
9:   IMP_2M    9                                                                
9:   HOSP_3M   10                                                               
9:   SURG_3M   11                                                               
9:   INJ_3M    12                                                               
9:   ILL_3M    13                                                               
9:   IMP_3M    14                                                               
9:   HOSP_M    15                                                               
9:   SURG_M    16                                                               
9:   INJ_M     17                                                               
9:   ILL_M     18                                                               
9:   IMP_M     19                                                               
9:   VISIT_Y1  20-21                                                            
9:   VISIT_Y2  22-23                                                            
9:   CDAYS_Y2  29-31                                                            
9:   PMEET_Y2  32                                                               
9:  @33 CHOUR_Y2 5.3                                                            
9:   VISIT_Y3  38-39                                                            
9:   CDAYS_Y3  40-42                                                            
9:   PMEET_Y3  43                                                               
9:  @44 CHOUR_Y3 5.3                                                            
9:   VISIT_T   49-51                                                            
9:   CDAYS_T   52-54                                                            
9:   PMEET_T   55-56                                                            
9:  @57 CHOUR_T 6.3
using "09795-0003-Data.txt";                                                                               
#delimit ;

label var ACTPS_36  "Achenbach Total Prob. Sum Score at 36M"

*/

/*

// SUMMARY SCORES DATASET CODEBOOK
// bits from the SAS file
// go to page 261 of the pdf/manual coded with (3)

;                                                                               
DATA;                                                                           
MISSING A B C D E F G H I J K L M N O P Q R S T U V W X Y Z;                    
INFILE 'sumscore' LRECL=80 N=6;                                                 
INPUT                                                                           

#1   FIELD_0   11                                                               
#1   FIELD_0M  12                                                               
#1   GHQ_0     18-19                                                            
#1   GHQ_0M    20-21                                                            
#1   BATET_12  22-24                                                            
#1   BATEF_12  25-26                                                            
#1   BATES_12  27-28                                                            
#1   BATEP_12  29-30                                                            
#1   BATEA_12  31-32                                                            
#1   BATTO_12  33-35                                                            
#1   BATUS_12  36-37                                                            
#1   BATPE_12  38-39                                                            
#1   BATET12M  40-41                                                            
#1   BATEF12M  42                                                               
#1   BATES12M  43                                                               
#1   BATEP12M  44                                                               
#1   BATEA12M  50                                                               
#1   BATTO12M  51-52                                                            
#1   BATUS12M  53                                                               
#1   BATPE12M  54                                                               
#1   GHRCH_12  55-56                                                            
#1   GHRRS_12  57-58                                                            
#1   GHRPH_12  59-60                                                            
#1   GHRI_12   61-62                                                            
#1   GHRCH12M  63                                                               
#1   GHRRS12M  64                                                               
#1   GHRPH12M  65                                                               
#1   GHRI12M   66                                                               
#1   GHQ_12    67-68                                                            
#1   GHQ_12M   69-70                                                            
#1   HOMTO_12  76-77                                                            
#1   HOMRE_12  78-79                                                            
#1   HOMAC_12  80                                                               
#2   HOMOR_12  1                                                                
#2   HOMPM_12  2                                                                
#2   HOMIN_12  3                                                                
#2   HOMVA_12  4                                                                
#2   HOMTO12M  5-6                                                              
#2   HOMRE12M  7-8                                                              
#2   HOMAC12M  9                                                                
#2   HOMOR12M  10                                                               
#2   HOMPM12M  11                                                               
#2   HOMIN12M  12                                                               
#2   HOMVA12M  13                                                               
#2  @19 KIDAT_12 5.3                                                            
#2  @24 KIDAC_12 5.3                                                            
#2  @29 KIDTO_12 5.3                                                            
#2  @34 CODQC_12 5.3                                                            
#2  @39 CODQP_12 5.3                                                            
#2  @44 CODQT_12 5.3                                                            
#2   CODQC12M  49-50                                                            
#2   CODQP12M  51-52                                                            
#2   CODQT12M  53-54                                                            
#2   GHRCH_24  55-56                                                            
#2   GHRRS_24  57-58                                                            
#2   GHRPH_24  59-60                                                            
#2   GHRI_24   61-62                                                            
#2   GHRCH24M  68                                                               
#2   GHRRS24M  69                                                               
#2   GHRPH24M  70                                                               
#2   GHRI24M   71                                                               
#2   GHQ_24    72-73                                                            
#2   GHQ_24M   74-75                                                            
#2  @76 KIDAT_24 5.3                                                            
#3  @1 KIDAC_24 5.3                                                             
#3  @6 KIDTO_24 5.3                                                             
#3  @11 KIDR_24 5.3                                                             
#3   RBCL_24   16-17                                                            
#3   RBCL24M   18-19                                                            
#3  @25 STETO_24 5.3                                                            
#3  @30 STEGH_24 5.3                                                            
#3  @35 STEAC_24 5.3                                                            
#3  @40 STETA_24 5.3                                                            
#3   STETO24M  45-46                                                            
#3   STEGH24M  47-48                                                            
#3   STEAC24M  49-50                                                            
#3   STETA24M  51-52                                                            
#3   CHEEK_30  53-54                                                            
#3   CHEEK30M  55                                                               
#3   ACTPS_36  56-58                                                            
#3   ACEXS_36  59-60                                                            
#3   ACINS_36  61-62                                                            
#3   ACSWS_36  68-69                                                            
#3   ACDPS_36  70-71                                                            
#3   ACSPS_36  72-73                                                            
#3   ACSOS_36  74-75                                                            
#3   ACAGS_36  76-77                                                            
#3   ACDSS_36  78-79                                                            
#4   ACOPS_36  1-2                                                              
#4   ACTPT_36  3-4                                                              
#4   ACEXT_36  5-6                                                              
#4   ACINT_36  7-8                                                              
#4   ACTPS36M  9-11                                                             
#4   ACEXS36M  12-13                                                            
#4   ACINS36M  14-15                                                            
#4   ACSWS36M  16-17                                                            
#4   ACDPS36M  18-19                                                            
#4   ACSPS36M  20-21                                                            
#4   ACSOS36M  27-28                                                            
#4   ACAGS36M  29-30                                                            
#4   ACDSS36M  31-32                                                            
#4   ACOPS36M  33-34                                                            
#4   GHRCH_36  35-36                                                            
#4   GHRRS_36  37-38                                                            
#4   GHRPH_36  39-40                                                            
#4   GHRI_36   41-42                                                            
#4   GHRCH36M  43                                                               
#4   GHRRS36M  44                                                               
#4   GHRPH36M  45                                                               
#4   GHRI36M   46                                                               
#4   GHQ_36    47-48                                                            
#4   GHQ_36M   49-50                                                            
#4   HOMTO_36  56-57                                                            
#4   HOMLE_36  58-59                                                            
#4   HOMLA_36  60                                                               
#4   HOMPE_36  61                                                               
#4   HOMWA_36  62                                                               
#4   HOMAS_36  63                                                               
#4   HOMMO_36  64                                                               
#4   HOMVA_36  65                                                               
#4   HOMAC_36  66                                                               
#4   HOMTO36M  67-68                                                            
#4   HOMLE36M  69-70                                                            
#4   HOMLA36M  71                                                               
#4   HOMPE36M  72                                                               
#4   HOMWA36M  73                                                               
#4   HOMAS36M  74                                                               
#4   HOMMO36M  80                                                               
#5   HOMVA36M  1                                                                
#5   HOMAC36M  2                                                                
#5   MOSAC_36  3-4                                                              
#5   MOSAB_36  5-6                                                              
#5   MOSAV_36  7-8                                                              
#5   MOSAC36M  9-10                                                             
#5   MOSAB36M  11-12                                                            
#5   MOSAV36M  13-14                                                            
#5   RBCL_36   15-16                                                            
#5   RBCL36M   17-18                                                            
#5  @19 CODQC_36 5.3                                                            
#5  @24 CODQP_36 5.3                                                            
#5  @34 CODQT_36 5.3                                                            
#5   CODQC36M  39-40                                                            
#5   CODQP36M  41-42                                                            
#5   CODQT36M  43-44                                                            
#5  @45 STETO_36 5.3                                                            
#5  @50 STEGH_36 5.3                                                            
#5  @55 STEAC_36 5.3                                                            
#5  @60 STETA_36 5.3                                                            
#5   STETO36M  65-66                                                            
#5   STEGH36M  67-68                                                            
#5   STEAC36M  69-70                                                            
#5   STETA36M  71-72                                                            
#5   DCFIRST4  78-79                                                            
#6   FAGE      1-2                                                              
#6   LOS       3-5                                                              
#6   F34NMR    6                                                                
#6   F7CCAGE   7-10                                                             
#6   F20CCAGE  11-14                                                            
#6   F22CCAGE  20-23                                                            
#6   F34CCAGE  24-27                                                            
#6   F36CCAGE  28-31                                                            
#6   F38CCAGE  32-35                                                            
#6   F47CCAGE  36-39                                                            
#6   F54CCAGE  40-43                                                            
#6   F56CCAGE  44-47                                                            
#6   F61CCAGE  48-51                                                            
;                                                                               

*/




