
* THIS VERSION: September 28 2019

clear all

use "${folddata}\datapaper.dta", clear

// **************
// birth outcomes
// ************** 

// NHIBW     Health index
// BMI_B     Body mass index at birth
// INV_BW    Birth weight
// INV_ANGA  Gestational age
// F3AV5     Head circumference at birth (cm)
// F3AV4     Infant length at birth (cm)

macro def B INV_BW F3AV4 BMI_B INV_ANGA NHIBW F3AV5

label var INV_BW    "Birth Weight (gm)"
label var F3AV4     "Length at Birth (cm)"
label var BMI_B     "Body Mass Index at Birth"                                                            
label var INV_ANGA  "Gestational Age (weeks)"  
label var NHIBW     "Neonatal Health Index"
label var F3AV5     "Head Circumference at Birth (cm)"

// *******************
// infant demographics
// *******************

// BRTH_ORD  Birth Order: 1, 2, 3+

gen firstborn = cond(BRTH_ORD == 1, 1, 0) if BRTH_ORD != .

macro def B $B boy firstborn

label var boy       "Infant was a boy"
label var firstborn "Infant is a first-born"

// *******************
// mother demographics
// *******************

// F3AMAGE   Maternal Age at Birth
// F3BV59    Maternal Education: 1-LT 9th Grade; 2-9th-12th Grade; 3-High School Grad; 4-Some College; 5-College or Mc
// BLACK     Black Maternal Race
// HISPANIC  Hispanic Maternal Race
// F3BV64    Marital Status: l-Married; 2-Separated; 3-Divorced; 4-Widowed

gen married = cond(F3BV64 == 1, 1, 0) if F3BV64 != .
gen highdrop = cond(F3BV59 < 3, 1, 0) if F3BV59 != .
gen highgrad = cond(F3BV59 == 3 | F3BV59 == 4, 1, 0) if F3BV59 != .
gen collgrad = cond(F3BV59 == 5, 1, 0) if F3BV59 != .

macro def X F3AMAGE married highdrop highgrad collgrad BLACK HISPANIC

label var F3AMAGE    "Age of the mother"
label var married    "Mother was married"
label var highdrop   "Mother was high school dropout"
label var highgrad   "Mother was high school graduate"
label var collgrad   "Mother was college graduate"
label var BLACK      "Black Maternal Race"
label var HISPANIC   "Hispanic Maternal Race"

// ********
// outcomes
// ********

macro def Y F57_1_ ACTPS_36 THCS_CUM SHCI_CUM STETO_36 F63V7A BMI_36 GHRI_36 // same order as in Table 3 of JAMA paper  
 
label var F57_1_    "Cognitive Development Index"
label var ACTPS_36  "Behavioral Competence Index"
label var THCS_CUM  "Morbidity Index"
label var SHCI_CUM  "Serious Morbidity Index"
label var STETO_36  "Functional Status Index"
label var F63V7A    "Length (cm)"
label var BMI_36    "Body Mass Index"
label var GHRI_36   "General Health Ratings Index"

macro def Y F57_1_ THCS_CUM GHRI_36 // these are the outcomes we used  

// *********
// treatment
// *********

macro def D treat

label var treat "Treatment status"

