
// estimation based on the Primary Analysis Group (N=985) 

use "${folddata}\Primary-Analysis-Dataset.dta", clear

// We use the following measures for the health endowment, recorded at birth:
//
// 1. NHIBW: Health Index 
//    see page 279 of the codebook file labeled with (2)
//    it's a residual not explained by birth weight, using duration from date of birth to date of hospital discharge
// 2. INV_BW: Weight
// 3. F3AV4: Length
// 4. F3AV5: Head Circumference
// 5. F3AMAGE: Maternal Age               
// 6. INV_ANGA: Gestational Age

macro def preIHDP NHIBW INV_BW F3AV4 F3AV5 INV_ANGA F3AMAGE

// keep only infants without missing data

egen tmp = rowmiss($preIHDP)
drop if tmp > 0
drop tmp

// factor analysis: 87% explained by two factors

factor $preIHDP, pcf //factors(3)
rotate

// the second factor captures something on top of objective proxies of health status

predict f1 f2, bartlett // regression

label var f1 "Health Endowment - 1st Factor"
label var f2 "Health Endowment - 2nd Factor"

// generate relevant variables

gen treat = TG == "I"
gen boy    = INV_SEX == 1
gen black  = BLACK == 1
gen hisp   = HISPANIC == 1
gen strata = BWG == "H"
replace INV_BW = INV_BW/1000 
egen site = group(SITE)

label var treat  "Treatment"
label var boy    "Infant is a boy"
label var black  "Black Maternal Race"
label var hisp   "Hispanic Maternal Race"
label var strata "Randomization strata"
label var site   "Site/cluster"

sort IHDP
compress

// sample selection:
// only primary analysis group with non-missing observations on health status at birth (N=929)

saveold "${folddata}\datapaper.dta", replace

