
* THIS VERSION: August 19, 2020
* compute QCD from raw data

// setup variables

foreach v of varlist F57_1__std THCS_CUM_std GHRI_36_std {
		
	qui cap drop intY0_`v'
	qui cap drop intY1_`v'
	qui cap drop slpY0_`v'
	qui cap drop slpY1_`v'
	qui cap drop QDG_high_`v'
	qui cap drop QDG_low_`v'
	qui cap drop _q
}
	
foreach v of varlist F57_1__std THCS_CUM_std GHRI_36_std {
		
	qui gen	intY0_`v' = .   // q-intercept for Y0|Theta
	qui gen intY1_`v' = .   // q-intercept for Y1|Theta

	qui gen	slpY0_`v' = .   // q-slope for Y0|Theta
	qui gen slpY1_`v' = .   // q-slope for Y1|Theta
}


macro def W INV_BW_std 

foreach v of varlist F57_1__std THCS_CUM_std GHRI_36_std {

	local i = 0

	forvalues q = 5(5)95 {
			
			local i = `i' + 1
			local qtilde = `q'/100
			
			qui cap gen _q = .
			replace _q = `q' in `i'
				
			// Intercept and slope - Y0 
				
			qui qreg `v' $W if $D == 0, quantile(`qtilde')

			qui cap replace	intY0_`v' = _b[_cons] in `i'
			qui cap replace	slpY0_`v' = _b[$W]    in `i'
					
			// Intercept and slope - Y1 
				
			qui qreg `v' $W if $D == 1, quantile(`qtilde')

			qui cap replace	intY1_`v' = _b[_cons] in `i'
			qui cap replace	slpY1_`v' = _b[$W]    in `i'
			
	} 
}	

br _q intY1* slpY1* intY0* slpY0* if _q != .

// compute QCD

local high_F57_1__std   = 1.048193
local low_F57_1__std    = -0.5647687

local high_THCS_CUM_std = 1.042546
local low_THCS_CUM_std  = -0.5642121

local high_GHRI_36_std = 1.045546
local low_GHRI_36_std  = -0.5632206

foreach v of varlist F57_1__std THCS_CUM_std GHRI_36_std {

	qui sum slpY0_`v' if _q == 50
	local l0 = r(mean)

	qui sum intY0_`v' if _q == 50
	local u = r(mean)
	
	qui gen QDG_high_`v' = (slpY1_`v' - `l0')*`high_`v'' + intY1_`v' - `u'
	qui gen QDG_low_`v'  = (slpY1_`v' - `l0')*`low_`v''  + intY1_`v' - `u'
}

// graph QCD

local   title_F57_1__std = "Cognitive Development Index"
local title_THCS_CUM_std = "Morbidity Index"
local  title_GHRI_36_std = "General Health Ratings Index"

// data for graphs in R
// Figure 5:
// sort data tau
// br _q QDG_high_* QDG_low_* if _q != .
	
foreach v in F57_1__std THCS_CUM_std GHRI_36_std {

	#delimit ;
	twoway (line QDG_high_`v' QDG_low_`v' _q, lpattern(dash solid) lcolor(black red))
		   if inrange(_q,6,94),		   
		   legend(order(1 "HLBW" 2 "LLBW") size(vsmall))
		   ytitle("") yscale(range(-1.8 1.8)) ylabel(-1.5(0.5)1.5, labsize(tiny))
	       xtitle(quantile) xscale(range(5 95)) xlabel(10(5)90, labsize(tiny))
		   subtitle("`title_`v''")
		   scheme(s1color)
		   saving(qdg_`v'.gph, replace);
	#delimit cr
}	

qui graph combine "qdg_F57_1__std.gph" "qdg_THCS_CUM_std.gph" "qdg_GHRI_36_std.gph", row(1) scheme(s1color)

erase "qdg_F57_1__std.gph"
erase "qdg_THCS_CUM_std.gph"
erase "qdg_GHRI_36_std.gph"






















