
* FIRST VERSION: May 29 2015
* THIS VERSION: Jul 29 2023

clear all
program drop _all
set mem 1200m
set more off
set maxvar 32767 
set matsize 11000

cap log close

// these are Erich's paths

cap global foldwork "C:\Users\Erich\Dropbox (Personal)\BLR paper\data\IHDP"
cap global foldwork "\\tsclient\C\Users\Erich\Dropbox (Personal)\BLR paper\data\IHDP"

// working folders

cap cd "${foldwork}"

cap global folddata "$foldwork\raw data"
cap global foldgr   "$foldwork\graphs"
cap global foldlog  "$foldwork\output"

// outreg options   

global ast = ""
global nolabel = "label"
global stat = ""
global nbdec = 3  
global nsdec = 3  
global nadec = 3 
global tab "excel"

// -----
// CODES
// -----
// activate do files within each block below to replicate results

// Step 1: read raw data and create working sample

do "${foldwork}\import_data.do"
do "${foldwork}\make_data.do"

// Step 2: descriptives and balancing tests

do "${foldwork}\macros-setup.do"
do "${foldwork}\descriptives-rev-sep-2023.do"

// Step 3: background graphs using QTE

do "${foldwork}\macros-setup.do"
do "${foldwork}\rank-invariance-rev-sep-2023.do"

// Step 4: measurement equations

*do "${foldwork}\macros-setup.do"
*do "${foldwork}\IHDP-measurements-equations-june-2023.do"

// Step 5: SIMEX estimates of QCD 

*do "${foldwork}\macros-setup.do"
*qui do "${foldwork}\simex-SIMstep.do"
*qui do "${foldwork}\simex-EXstep.do"
*do "${foldwork}\simex-output.do"     // calls raw-data-output.do, which computes QCD from raw data

// Step 5.1: plot results

*do "${foldwork}\simex-graphs-bootstrap-july2023.do"

// Step 6: bootstrap by income group

*do "${foldwork}\macros-setup.do"
*qui do "${foldwork}\simex-SIMstep.do"
*qui do "${foldwork}\simex-EXstep.do"
*do "${foldwork}\simex-output-by-income.do"

// Step 6.1: plot results

*do "${foldwork}\simex-graphs-by-income-july2023.do"

// Step 7: sensitivity checks

*do "${foldwork}\_may23_checks.do" // graphs for loadings estimated using different control variables




