
* THIS VERSION: September 26 2019

// SIMEX: EXtrapolation step

cap program drop EX
program define EX, rclass

	//  INPUTS: variable list, the first variable must be W1
	//
	// NEEDS OUTPUT FROM PROGRAM SIM

	syntax varlist

	// local variables defined in the procedure
	
	tokenize `varlist'
	
	local w1 `1'   // measurement
	macro shift
	local out `*'  // outcome list

	tempvar rv rv2

	// ***********************
	// DEFINITION OF VARIABLES
	// ***********************
	
	// define variables that will eventually contain QSIMEX intercepts (int_) and slopes (slp_) at different quantiles
	// these variables are defined:
	// -- for all outcomes in $Y
	// -- at all quantiles (5...95)

	foreach v of varlist `out' {
		
		qui cap drop lY0_`v'
		qui cap drop qY0_`v'
		qui cap drop lY1_`v'
		qui cap drop qY1_`v'
	}	
	
	foreach v of varlist `out' {
		
		qui gen	qY0_`v' = .   // q-intercept for Y0|Theta
		qui gen qY1_`v' = .   // q-intercept for Y1|Theta
		qui gen	lY0_`v' = .   // q-slope for Y0|Theta
		qui gen lY1_`v' = .   // q-slope for Y1|Theta
	}	
	
	// define quantile 
	
	qui cap drop tau
	qui gen tau = .
	
	// *******************
	// SIMEX EXTRAPOLATION
	// *******************

	qui gen  `rv' = (rho + 1)
	qui gen `rv2' = (rho^2 - 1)

	foreach v of varlist `out' {
		
		forvalues q = 5(5)95 {
		
			qui cap replace tau = `q' in `q'
	
			// control group: intercept and slope
	
			qui reg intY0_`v'_`q' `rv' `rv2' if rho != .
			qui replace qY0_`v' = _b[_cons] in `q'

			qui reg slpY0_`v'_`q' `rv' `rv2' if rho != .
			qui replace lY0_`v' = _b[_cons] in `q'
	
			// control group: intercept and slope
	
			qui reg intY1_`v'_`q' `rv' `rv2' if rho != .
			qui replace qY1_`v' = _b[_cons] in `q'

			qui reg slpY1_`v'_`q' `rv' `rv2' if rho != .
			qui replace lY1_`v' = _b[_cons] in `q'
		}
	} /* end of SIMEX */	
	
end



