
* THIS VERSION: September 26 2019

// SIMEX: SIMulation step

cap program drop SIM
program define SIM, rclass

	//  INPUTS: variable list, the first variable must be W1
	// OPTIONS:
	// _sigma: measurement error variance (default sqrt(0.05052481))
	//  _nrep: number of replications (default 10)

	syntax varlist [, _sigma(real 0.22477725) _nrep(integer 10)]

	// local variables defined in the procedure
	
	tokenize `varlist'
	
	local w1 `1'   // measurement
	macro shift
	local out `*'  // outcome list

	tempvar e w1t
	
	// ***********************
	// DEFINITION OF VARIABLES
	// ***********************
	
	// define variables that will eventually contain QSIMEX intercepts (int_) and slopes (slp_) at different quantiles
	// these variables are defined:
	// -- for all outcomes in $Y
	// -- at all quantiles (5...95)
	// values of these variables will be at diffent points _rho

	foreach v of varlist `out' {
		
		forvalues q = 5(5)95 {
		
			qui cap drop intY0_`v'_`q'
			qui cap drop intY1_`v'_`q'
			qui cap drop slpY0_`v'_`q'
			qui cap drop slpY1_`v'_`q'
		}
	}	
	
	foreach v of varlist `out' {
		
		forvalues q = 5(5)95 {
		
			qui gen	intY0_`v'_`q' = .   // q-intercept for Y0|Theta
			qui gen intY1_`v'_`q' = .   // q-intercept for Y1|Theta

			qui gen	slpY0_`v'_`q' = .   // q-slope for Y0|Theta
			qui gen slpY1_`v'_`q' = .   // q-slope for Y1|Theta
		}
	}	
	
	// define distance from the no-error case 
	
	qui cap drop rho
	qui gen rho = .
		
	// ******************
	// SIMEX REPLICATIONS
	// ******************
	
	local i = 0
	
	forvalues _rho = 0.1(0.1)2.1 {
	
		noi di "I am working on `_rho'"

		// STEP 1 - Set a value for _rho 
	
		local i = `i' + 1
		qui cap replace rho = `_rho' in `i'	
	
		// STEP 2 - For any given _rho, obtain `_nrep' draws and take their mean
	
		forvalues r = 1(1)`_nrep' { 

			// STEP 2.1 - generate the perturbation
		
			qui cap drop `e'
			qui cap drop `w1t'
			
			qui gen `e'   = `_sigma'*sqrt(`_rho')*rnormal(0,1)  // this is the perturbation
			qui gen `w1t' = `w1' + `e'

			// STEP 2.2 - estimate QR using the perturbated variable
			
			foreach v of varlist `out' {

				forvalues q = 5(5)95 {
				
					local qtilde = `q'/100
				
					// Intercept and slope - Y0 
				
					qui qreg `v' `w1t' if $D == 0, quantile(`qtilde')

					qui cap replace	intY0_`v'_`q' = cond(intY0_`v'_`q'[`i'] == ., 0, intY0_`v'_`q'[`i']) + _b[_cons] in `i'
					qui cap replace	slpY0_`v'_`q' = cond(slpY0_`v'_`q'[`i'] == ., 0, slpY0_`v'_`q'[`i']) + _b[`w1t'] in `i'
					
					// Intercept and slope - Y1 
				
					qui qreg `v' `w1t' if $D == 1, quantile(`qtilde')

					qui cap replace	intY1_`v'_`q' = cond(intY1_`v'_`q'[`i'] == ., 0, intY1_`v'_`q'[`i']) + _b[_cons] in `i'
					qui cap replace	slpY1_`v'_`q' = cond(slpY1_`v'_`q'[`i'] == ., 0, slpY1_`v'_`q'[`i']) + _b[`w1t'] in `i'
				
				} /* end of SIMEX replications for one outcome */

			} /* end of SIMEX replications for all outcomes */	
				
		} /* end of SIMEX contamination */
			
		// STEP 2.3 - take the mean across replications

		foreach v of varlist `out' {

				forvalues q = 5(5)95 {
		
					qui replace intY0_`v'_`q' = intY0_`v'_`q'[`i']/`_nrep' in `i'
					qui replace intY1_`v'_`q' = intY1_`v'_`q'[`i']/`_nrep' in `i'
					qui replace slpY0_`v'_`q' = slpY0_`v'_`q'[`i']/`_nrep' in `i'
					qui replace slpY1_`v'_`q' = slpY1_`v'_`q'[`i']/`_nrep' in `i'
				}
		}		
	}			
				
end


