
* THIS VERSION: Jul 12 2023

*version 15.0

*macro def X // Version #1: no controls
*local sigma = sqrt(0.29483986)

*macro def X $X i.site i.strata // Version #2: demographis of mothers + randomization
*local sigma = sqrt(0.03030798)
 
*macro def X $X boy firstborn i.site i.strata // Version #3: demographis of mothers + infant + randomization
*local sigma = sqrt(0.0778336)

local sigma = sqrt(0.0674299) // value used in the paper
*local sigma = sqrt(0.05052481)

set seed 27062007 // 1 to 6
set seed 13072023 // 7 to ...

// **********************
// RESIDUALIZED VARIABLES
// **********************

foreach v of varlist $Y INV_ANGA F3AV4 INV_BW F3AV5 {

	regress `v' $X if $D == 1
	qui predict `v'_res if e(sample), residuals
	qui replace `v' = `v'_res if e(sample)
	qui drop `v'_res
	
	regress `v' $X if $D == 0
	qui predict `v'_res if e(sample), residuals
	qui replace `v' = `v'_res if e(sample)
	qui drop `v'_res
}

// *************
// STD VARIABLES
// *************

foreach v of varlist $Y INV_ANGA F3AV4 INV_BW F3AV5 {

	egen `v'_std = std(`v')
	*gen `v'_std = `v'
}

// *******************
// COMPUTE E[THETA|Y0]
// *******************

// these are predictions from regressions of W on Y0 for D = 0
// these predictions are used to compute QCD as explained in the text

/*
foreach v in F57_1__std THCS_CUM_std GHRI_36_std {

	_pctile `v' if $D == 0, nq(100)
	return list

	cap gen y0hat = .
	
	foreach n of numlist 1(1)99 {
	
		qui gen dev`n' = (`v'-r(r`n')) if $D == 0
		qui replace y0hat = r(r`n') in `n'
	}
	
	cap gen thetahat = .
		
	foreach n of numlist 1(1)99 {
	
		reg INV_BW_std dev`n' if $D == 0 // regression of W on Y0 for D = 0
		
		qui replace thetahat = _b[_cons]  in `n' // this is the prediction
		qui drop dev`n'
	}	
}
*/

// ***********************
// ESTIMATES FROM RAW DATA
// ***********************

// run this part if interested in QCD from raw data, that is, using observed W instead of latent H

*do raw-data-output.do

// ************
// SIMEX INPUTS
// ************

macro def S INV_BW_std F57_1__std THCS_CUM_std GHRI_36_std

// ******************
// SIMEX CALCULATIONS
// ******************
/*
SIM $S, _sigma(`sigma') _nrep(50)
EX  $S

preserve

keep if tau != .
keep  tau qY0_* qY1_* lY0_* lY1_* 
order tau qY0_* qY1_* lY0_* lY1_* 

compress
saveold "${foldlog}\simex-data-std.dta", replace

restore
*/
// *********
// BOOTSTRAP
// *********

forvalues i=7(1)200 {

	preserve

	bsample, strata(strata site treat)

	SIM $S, _sigma(`sigma') _nrep(50)
	EX  $S

	keep if tau != .
	keep  tau qY0_* qY1_* lY0_* lY1_* 
	order tau tau qY0_* qY1_* lY0_* lY1_* 

	compress
	saveold "${foldlog}\simex-data-std-boot`i'.dta", replace

	restore
}













